package vg

  1. Overview
  2. Docs

Module VgSource

Declarative 2D vector graphics.

Consult the tutorial, the semantics and the image howto.

Open the module to use it, this defines only modules and types in your scope.

Fonts

Sourcemodule Font : sig ... end

Fonts.

Sourcetype font = Font.t

The type for fonts.

Sourcetype glyph = int

The type for glyphs. The integer represents a glyph identifier in a backend dependent font format.

Paths and images

Sourcetype path

The type for paths.

Sourcetype image

The type for images.

Sourcemodule P : sig ... end

Paths.

Sourcemodule I : sig ... end

Images.

Image renderers

Sourcetype renderer

The type for image renderers.

Sourcemodule Vgr : sig ... end

Image renderers.